#!/opt/concourse/worker/volumes/live/710bb6bc-6577-464e-44bc-c88ca709bfa0/volume/anaconda-navigator_1645725747695/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/Anaconda-Navigator.app/Contents/MacOS/python
from subprocess import call

call(["/opt/concourse/worker/volumes/live/710bb6bc-6577-464e-44bc-c88ca709bfa0/volume/anaconda-navigator_1645725747695/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/bin/anaconda-navigator"])
